#
# spec file for package joe
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           joe
Version:        4.6
Release:        3.4
Summary:        A Text Editor
License:        GPL-2.0-or-later
Group:          Productivity/Text/Editors
URL:            http://sourceforge.net/projects/joe-editor
Source:         http://downloads.sf.net/joe-editor/%{name}-%{version}.tar.gz
Source2:        de.po
Source3:        joe-rpmlintrc
Patch2:         joe-3.1-fix_isblanck_argument.patch
Patch3:         joe-3.3-warnings.patch
Patch7:         joe-3.7-additional_key_mappings.patch
Patch8:         joe-3.7-spec_association.patch
Patch10:        joe-sigiot.patch
Patch12:        joe-4.6-nonvoid-functions.patch
BuildRequires:  automake
BuildRequires:  libselinux-devel
BuildRequires:  ncurses-devel

%description
Joe is a powerful, easy to use, modeless text editor. It uses the same
WordStar keybindings used in Borland's development environment.

%prep
%setup -q
%patch -P 2
%patch -P 3
%patch -P 7
%patch -P 8
%patch -P 10
%patch -P 12 -p1

%build
autoreconf -fiv
export CFLAGS="%{optflags} -W -Wno-unused"
%configure \
  --docdir=%{_defaultdocdir}/%{name}
make %{?_smp_mflags}

%install
%make_install
for i in jmacs jpico jstar rjoe; do
  ln -s joe.1.gz %{buildroot}%{_mandir}/man1/$i.1.gz
done
rm -rf %{buildroot}/%{_datadir}/%{name}/lang

# Remove desktop entries to follow openSUSE guidelines for console applications
# See: https://lists.opensuse.org/opensuse-factory/2019-02/msg00377.html
rm -rf %{buildroot}%{_datadir}/applications/*.desktop

%files
%doc %{_defaultdocdir}/%{name}
%{_mandir}/man1/*
%{_mandir}/*/man1/*
%config %{_sysconfdir}/joe/*
%dir %{_sysconfdir}/joe
%dir %{_datadir}/%{name}
%dir %{_mandir}/ru
%dir %{_mandir}/ru/man1
%{_bindir}/*
%{_datadir}/%{name}/charmaps
%dir %{_datadir}/%{name}/syntax
%config(noreplace) %{_datadir}/%{name}/syntax/*
%{_datadir}/joe/colors
%{_datadir}/joe/colors/*.jcf

%changelog
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Feb 13 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Dropped .desktop files to follow openSUSE guidelines regarding console
  applications: https://lists.opensuse.org/opensuse-factory/2019-02/msg00377.html
- Dropped obsolete patch joe-4.6-desktop_files.patch
* Thu Jan  3 2019 Martin Pluskal <mpluskal@suse.com>
- Small packaging simplifications
- Lets enable selinux
* Thu Jan  3 2019 Enno Gotthold <egotthold@suse.com>
- Added patch to fix build on SLe_12_Sp3 and openSUSE_Leap_42.3
  * joe-4.6-nonvoid-functions.patch
* Thu Jan  3 2019 Enno Gotthold <egotthold@suse.com>
- Fixed broken build: Added patch which was forgotten to add to version control.
* Fri Nov 30 2018 Enno Gotthold <egotthold@suse.com>
- Add Patch joe-4.6-desktop_files.patch: Desktop Category was wrong.
- Update to version 4.6
  * Upgrade to Unicode 10.0.0. Add configure environment variable that allows
    you select Unicode 8.0.0, 9.0.0 or 10.0.0.
  * Install Gnome .desktop files for JOE. This allows you to use JOE in GUI
    "Open With" mouse actions.
  * Support strikeout and double-underline attributes for the few terminal
    emulators that support them. Use "stricken" and "dunderline" in the syntax
    files, or \s and \z in help screens and status line.
  * Fix bug where JOE would sometimes crash when editing shell scripts. This
    was due to an obscure bug in the syntax highlighter: 'reset' command (used
    for default state) was incorrectly messing with stack.
  * -highlighter_context was missing from many file types, which negated some
    improvements from the previous version.
  * Fixed signed char overflow with old style mouse events in large windows
  * Fix bug where path restart (//) was being applied to block filter command
    prompt. Strange things would happen if you had adjacent slashes in command
    arguments.
  * Allow ~ expansion but suppress path restart (//) in compiler error parsing.
    Restore default handling of SIGPIPE and SIGINT for shell commands. This
    fixes an issue where SIGPIPE doesn't terminate a process as expected, for
    example by the head -n 10 in: ^K R !sh -c 'while :; do echo y; done' |
    head -n 10. This issue only occurred in read/write to !, JOE already did
    the right thing for shell windows and the filter region through shell
    command.
  * Improve screen update algorithm so that spaces at the ends of lines are
    always emitted. This allows them to be preserved when cutting text with
    the mouse from a terminal emulator window.
  * Improve efficiency of screen update algorithm: JOE had been resetting
    attributes such as background color before performing cursor motions
    (probably as work around for bugs in old terminal emulators). This made
    screen update slow when there were many attributes, as with syntax
    highlighting and color schemes. It was also repeatedly emitting ESC [ K.
  * Switch JOE to issue scrolling commands, even at high baud rates (before
    this, JOE issued scrolling commands only at 19200 and below because it
    used to be that simple screen refresh was faster than scrolling in
    terminal emulators. But this is no longer true with complex screens
    involving color schemes, unicode and highlighting).
- Update to version 4.5
  * New color scheme feature, which can be accessed with ^T S or by setting
  * the -colors option.
  * 24-bit color support can be enabled by setting the COLORTERM environment
    variable to truecolor or 24bit.
  * Several schemes included in-the-box:
  * gruvbox by Pavel Pertsev
  * ir_black by Todd Werth
  * molokai by Tomas Restrepo
  * solarized by Ethan Schoonover
  * wombat by Lars H. Nielsen
  * xoria by Dmitriy Y. Zotikov
  * zenburn by Jani Nurminen
  * The current line can be highlighted by pressing ^T U or by enabling the
  - hiline option.
  * The gutter containing line numbers has a dynamic size based on the length
    of the file, rather than a fixed size of 10.
  * Updated all language syntax files to use comment_todo and string/comment
    contexts where appropriate.
  * Now pass character which invoked a macro to each macro step and call. If a
    macro step happens to be the 'type' command, the character which invoked
    the macro will be typed in. For example, this macro will type three 'X's.
    Before this change you got three NULs.
  * type,type,type X
  * Fix exsave: (^K ^X) should close file when a block is present in the
    window, and the file is unmodified (regression from ^C change in 4.2).
  * Fix regex assertions: they were not working because the character before
    the search position was not being loaded.
  * For jmacs: ^Q^J now again inserts \n in the string replace prompt. This
    broke beginning with JOE 4.0.
  * Don't try to open files for writing to check file access. This behaves
    better on unionfs mounts.
  * Fix stray blocks created after find/replace.
* Mon Jan 23 2017 mpluskal@suse.com
- Update to version 4.4:
  * Fix segfault due to buffer overrun.  This happens if a line
  with many backslashes appears in the status line context display.
  * Fix jmacs: ^X ^F and ^X ^B were not working
  * Build fixes for Solaris
  * Improve php highlighter: allow numbers in substitution variable names
  * Unicode tweak: treat private use characters (Co) as printable
  * Dockerfile highlighter: Add Docker new commands from 1.12,
  mark bad strings in arrays
  * Fix loading external charmaps
- Changes for version 4.3:
  * Improve memory usage by shrinking buffer header size and
  highlighter state size.
  * Improve performance of status line context display (which shows
  the first line of the function that the cursor is currently in).
  This feature was making JOE very slow on extremely large files with
  auto indent enabled (typically JSON or XML data files).  Now
  the syntax highlighter computes the context display (using a new
  syntax named context.jsf).
  * Add a mode 'title' to enable or disable the status line context
  display (previously autoindent mode was overloaded to do this).
  * Disable syntax highlighting and context display in very large
  files
  * Force more appropriate modes when we enter hex dump display:
  enable overtype, disable autoindent, wordwrap, ansi, picture.
  * Handle middle mouse button in "joe -mouse" mode (before it did
  nothing).  It's treated as paste (copy region to mouse) as
  expected.  (patch from Petr Olsak).
  * Do not kill region highlighting during incremental search (patch
  from Petr Olsak).
  * Negative numbers were not being recognized in blocks
  * PgUp/PgDn would try to scroll menu if the window above is a menu
  (it should do this only for completion menus associated with
  prompts)
  * Use 'LC_ALL=C sed' to get JOE to compile in OS X.
  * Forward direction delimiter matching where the delimiters do
  not begin with special characters (for example in Verilog
  "begin" / "end") was not working.
  * Get mouse to work in menus: this broke in 4.1
  * Character classes with ranges were not working for UTF-8 (as in \\[a-z])
  * Apply spec highlighting to .spec files
  * Gracefully handle short terminals: fix segfaults which occur when
  trying to shrink terminal while many windows are on the screen or
  while turning on help with a short terminal.  Fix similar bugs
  involving the skiptop option.  JOE now works even if the terminal
  height is only one line.
- Refresh patches
- Small spec file cleanup
* Mon May  2 2016 pth@suse.de
- Update to 4.2:
  * New or improved syntax files for the following languages:
  * Dockerfile
  * Usability Enhancements
  * The top Google help searches for JOE include:
  * How do I save and exit?  The startup copyright notice
  has been replaced with basic help for beginners
  * How do I dismiss the region highlighting?
  Changed to Ctrl-C will do it.
  * How do I close all files and exit?  Now Ctrl-K Q does this.
  * Restyle the help screens.
  * Remove time and "Ctrl-K H for help" message from status bar.
  * Add ^KH for help to search and replace prompts.
  * Provide aborthint and helphint options
  * Enable -noxon by default (disable ^S/^Q flow control).
  * Document ESC X (command prompt) in the help screens.
  * "joe --help" now prints all command line options.
  * Other Enhancements
  * Tags search now tries to find the tags file in parent directories
  if it does not exist in the current directory and if the TAGS
  environment variable was not set.
  * Built-in calculator can now print and accept numbers in binary,
  octal and engineering formats:
  __dec__	12_345
  __eng__	12.345_0e3
  __bin__	0b11_0000_0011_1001
  __oct__	0o3_0071
  __hex__	0x3039
  * Built-in calculator now prints and accepts separating underscores
  for clarity.
  * Enhanced calculator statistics functions:
  * __dev__ computes standard deviation with full population
  * __samp__ computes standard deviation with sample of population
  * Linear regression analysis.  Select a region of x
  and y values, then:
  * __lr__(x)   provide estimate of y given x
  * __rlr__(y)  provide estimate of x given y
  * __Lr__, __lR__, __LR__: log, exponential, power regression
  * Calculator region functions now assume the entire buffer if no
  region is set.
  * Tab completion now works at the calculator prompt (and in all
  prompts which allow numeric input, such as ^KL- go to line).
  * Make new regex engine (from JOE 4.1) more compatible with the
  classic engine.  \\y is now shorthand for \\(\\.\\\*\\), so that it does
  what \\\* did in the old engine.  Also:
  * \\. no longer matches newline.
  * \\\* matches shortest match, not longest match.
  * Add -left and -right options to control the amount scrolling when
  the cursor moves past the left or right edge of the screen.
  * Bugs fixed
  * Fix use after free bug which shows up as a crash in OpenBSD
  * Fix bug where indent step value was not shown on ^T menu
  * Fix bug where setting margin doesn't work on big-endian systems
  * Fix issue where highest valued unicode character equivalent was
  not translating to its corresponding 8-bit character.  Effect
  of this was that Delete key was not working in shell windows in
  ASCII character set.
  * Standard deviation calculator function was not producing correct
  results.
  * Allow koi8r and koi8-r for KOI8-R in joe_getcodeset (which is only
  used if there is no setlocale).
  * Guess_crlf forced UNIX line endings for new files even though
  crlf was set.  Now crlf is left alone if guess_crlf can not
  determine the line ending.
  * If cursor was at end of a long line and you switched to hex dump
  display mode, then hex dump was scrolled.  Now scroll offset is
  reset when you switch to hex display mode.
- Resynched patches:
  joe-3.3-warnings.patch
  joe-3.7-spec_association.patch
- Update German translations
* Sun Oct  4 2015 jengelh@inai.de
- Update to new upstream release 4.1
  * JOE can now edit UTF-16BE and UTF-16LE files. It does this by
  converting them to UTF-8 during load and back to UTF-16 during
  save.
  * Within JOE, native byte order is called UTF-16 and reversed order
  is called UTF-16R. Changing the encoding (with ^T E) between
  UTF-8, UTF-16 and UTF-16R will make JOE convert the file to the
  desired encoding on save.
  * New regular expression engine, which is a compiled Thompson NFA
  matcher. Now supports alternatives "X\|Y", grouping and submatch
  "a\(inside\)b", repetition ranges "x\{3,5}" for "xxxx\?x\?".
  * Unicode 8.0 character class support.
- Use shorter download URL
- Remove joe-codecleanup.patch (code to replace is no longer there),
  remove joe-3.1-terminate_buffer.patch (code changed to const).
* Sat Sep 19 2015 mpluskal@suse.com
- Actually fix download url
* Wed Jul  8 2015 pth@suse.de
- Fix source URI.
- Update and fix german messages.
- Add a rpmlintrc file to stop rpmlint from complaining about
  files marked as config but not in /etc.
* Wed Jun 17 2015 thehejik@suse.com
- Version update to 4.0:
  - JOE now has pop-up shell windows with full terminal emulation
    and shell commands that can control the editor. Hit F1 - F4 to bring up a shell window.
  - See Pop-up shell feature for a full description.
  - The status command (^K SPACE) can now be customized using the same syntax
    as the status bar. Look for smsg and zmsg in joerc to see how to do this.
    parserr (the error parser) will parse only the highlighted block if it's set.
    Before it always parsed the entire buffer.
  - Now there is a per-buffer concept of current directory. This was added to
    make the pop-up shell windows work better, but it's useful in general.
  - At file prompts you can begin a new anchored path without having to delete
    the old one. It means that ~jhallen/foo//etc/passwd is translated to /etc/passwd.
  - Prompt windows are now highighted to indicate which parts of the path are
    being dropped. There is a syntax file for this: filename.jsf
  - The error parser now ignores ANSI sequences (some versions of grep
    color their results, now JOE can still parse it).
  - Temporary messages are now dismissed by keyboard input only. Before, they
    could also be dismissed by shell input.
  - Tags search now supports multiple matches. ^K ; can be configured to
    either provide a menu of the matches or to cycle through them.
  - Tags search will now match on the member name part of member functions
    ('fred' will match 'myclass::fred').
  - Tags search will prepend the path to the tags file file name in the tags
    file. This is important when JOE finds the tags file via the TAGS
    environment variable.
  - Remove ` as quote character from incremental search.
  - Clean up documentation, convert much of it to Markdown.
- Cleanup with spec-cleaner
- Drop languages as they don't work at all
- refreshed patches:
  * joe-3.1-fix_isblanck_argument.patch
  * joe-3.1-terminate_buffer.patch
  * joe-3.3-warnings.patch
  * joe-3.7-additional_key_mappings.patch
  * joe-3.7-spec_association.patch
  * joe-codecleanup.patch
  * joe-sigiot.patch
- deleted patches:
  * joe-activate_po.patch.bz2
  * joe-fr_trans.patch
* Tue Nov 26 2013 jengelh@inai.de
- Enable parallel build and kill %%clean
* Wed Mar  6 2013 seife+obs@b1-systems.com
- fix build with automake-1.13.1
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Oct  5 2011 uli@suse.com
- cross-build fix: use %%configure macro
* Sat Jul  9 2011 lazy.kent@opensuse.org
- Convert Russian and Ukrainian docs and locales from KOI8 to
  UTF-8.
- Corrected License tag.
- Use full URL for Source.
* Mon Oct 26 2009 pth@suse.de
- Fix yet another case of stack smashing.
* Mon Oct 26 2009 pth@suse.de
- Remove lang_additions.bz2 obsoleted by inclusion in the gettextization
  patch.
* Fri Oct 23 2009 pth@suse.de
- Fix SIGIOT in autoindent (bnc#548327)
- Minor code cleanup.
- Redo the gettextisation patch (include all files added by tarball
  and gettextize).
- Update German translation.
* Tue Aug 11 2009 pth@suse.de
- Make syntax files config(noreplace) so that updates don't overwrite
  modifications.
* Wed Feb 25 2009 pth@suse.de
- Fix typo in ftyperc (bnc#476435).
* Thu Jan 22 2009 pth@suse.de
- Remove obsolete patch
- Fix file list
- Split and rename joe-3.0-rc.patch, move syntax mapping from j*rc
  to ftyperc.
* Wed Jan 21 2009 pth@suse.de
- Use gettext autoconf macros and makefiles.
- Added complete germen translation.
- Update to 3.7
  Changes in 3.7:
  - backspace/DEL means 'n' in replace prompt for better emacs
    compatibility
  - Menus are now made up of macros instead of options.
    New commands:
  menu	Prompt for a menu to display with tab
  completion.
  mode	Prompt for an option to change with tab
  completion.
  Menus are defined in joerc file with :defmenu command.
  Menu entries are the pair: macro string.  String is a
  format string displayed in the menu.  Macro is executed
  when then menu entry is selected.
  Use this to add your own macros to ^T.
  - ^T is now a user definable menu system
  - Treat \ as a quote character for file I/O.  Now you can edit
    files like !test with \!test
  - Print NULs in default search string.  Handle many \s properly.
  - Allow backslashes in file names
  - Fix %%A to print unicode
  - Charles Tabony's (vectorshifts's) highlighter stack patch
  - ! is relace all in replace prompt
  - Turn off UTF-8 when we enter hex mode
  - Call ttsig on vfile I/O errors.
  - Abort cleanly when malloc returns NULL
  - Add reload command to reload file from disk
  - Modify configure scrips to use docdir for extra documents and
    datadir/joe for syntax and i18n files.
  - Don't use bold yellow, it's bad for white screens
  - Fix TeX highlighter: don't highlight "
  - Make mail.jsf more forgiving for those of us who still use old
    UNIX mail
  - Fix file rename bugs
  - Improve ubop: can reformat a block of paragraphs again.
    Reformat of adjacent indented paragraphs working again.
  - Improve XML highlighter: allow \r in whitespace
  Changes in 3.6:
  - Preserve setuid bit
  - Fix bug where backup file did not get modtime of original
  - New diff highlighter
  - Fix paragraph format when overtype is on
  - Fix non-french spacing
  - Fix bug with joe +2 on single line files
  - Add syntax file for .jsf files
  - Add ASCII table to joerc help
  - ^KD renames file
  - Improve HTML highlighter... if you see <? it's probably a script...
  - Check for EINTR from ioctl
  - > allowed in xml content
  - Add -flowed option: adds a space after paragraph lines.
  - Fix German and French .po files: they were cause search&replace to break.
  - Look at LC_MESSAGES to get the language to use for editor messages.
  - Added -no_double_quoted and -tex_comment for TeX
  - Added -break_symlinks option and changed -break_links option to not
    break symbolic links.
  - Paragraph format of single line paragraph is indented only if autoindent
    is enabled.
  - Guessindent no longer overrides istep if indendation is space.
  - Fix low limit of lmargin
  - Allow inserting file in rectangle mode even if selected rectangle is
    zero-width.
  - .js is Javascript
  - Fix ^G in perl mode when you hit it on second brace in:
  {\'
  \'}
  - Fix LUA highlighter
  - Improved conf.jsf
  - Added local option (-nobackup) to suppress backup files
  - Add Matlab syntax file
  - Improve mail syntax highlighter
  - Fix crash when calling syntax file as subroutine
  - Get "ctags" tag search to work again
  - Fix crash when JOE tries to write to unwritable file
  - Fix crash when entering blank macro ESC x <return>
  - Improve Verilog highlighter
  - Fix crash when typing ESC x !ls
  - Add C++ keywords to highlighter
  - Added RPM spec file syntax spec.jsf
  - Improve 'istring' (.jsf command)
  - Update French .po file
  - Fix infinite search/replace loop bug
  - New feature: insert status line format string using 'txt'
  - Update Russion .po file
  - Update Russian manpage
  - Update jicerc Russian rc file
  - Fix lock prompt message
  - Add Ukrainian .po file
* Fri Apr  4 2008 pnemec@suse.cz
- change rpm spec file color #333570 (dim white -> magenta)
* Sat Jun 23 2007 pth@suse.de
- Add a germen translation by Jan Engelhardt that doesn't break hotkeys.
- Patch by Jan Engelhardt to fix handling of locale categories.
* Mon Apr  2 2007 cthiel@suse.de
- added BuildRequires: ncurses-devel
* Sat Jul 22 2006 cthiel@suse.de
- update to 3.5
  * Fix $# in shell highlighter.
  * Fix .in files in ftype
  * Tags file patch: allows you to put a path in TAGS environment variable.
  * Fix possible querysave bug.
  * Fix query window bug: cursor was not left in original windows for new
    multi-line query window thing.
  * Fix bug where we could not find ^@
  * Accept ,start,size notation only if it is correct.
  * Fix bug from undo_keep: undo_keep has to be a multiple of 2 for redo to
    work properly.
  * New undo_keep option.
  * Add built-in joerc file.
  * Fix menu bug: coredump on left arrow.
  * allow |comments| in gettext strings.
  * dnelson's patches for large files, tty.c include file problems and
    $(srcdir).
  * new syntax files: m4 joerc
  * use hash table in rc file parser.
  * use hash table in syntax parser.
  * add auto-expanding hash table.
  * i18n of other single-key prompts.  add joe_gettext to yncheck.
  * fix bug coredump when doing multi-file search and replace
  * internationalized y/n handling.
  * new spell check macro which uses 'language'
  * fix sh highlight bug: do not try to highlight $( )
  * query windows can now be multi-line.  Also they should handle wide
    characters properly.
  * you can now type a macro right into the ESC X prompt.
  * New * Startup Log * window catches .jsf file errors.
* Tue May 30 2006 cthiel@suse.de
- update to 3.4
  * Paragraph reformatter and word wrap now handle '*' and '-' bullet lists.
  * Better internationalization (i18n)
  * Multi-file search and replace
  * Build and grep window work more like Turbo-C: the messages window is
    forced onto the screen when you hit ^[ = and ^[ -.
  * Syntax highlighter definition files (.jsf files) can now have
    subroutines.  This eases highlighter reuse: for example, Mason and PHP
    can share the HTML highlighter.
  * You can now define which characters can indent paragraphs.  Also the
    default list has been reduced so that formatting of TeX/LaTeX files
    works better.
  * Highlighting now uses less CPU time and always parses from the beginning
    of the file (the number of sync lines option is deprecated).
  * File selection menu/completion-list is now above the prompt (which is
    more like bash).  Also it is transposed, so that it is sorted by columns
    instead of rows.
  * "Bufed" (prompt for a buffer to edit), works like other file prompt
    commands: it's a real prompt with history and completion.
  * Automatic horizontal left scroll jumps by 5-10 columns.
  * New syntax files: troff, Haskell, Cadance SKILL, REXX, LUA, RUBY.  Many
    of the existing syntax files have been improved.
- removed joe-3.0-processing.patch, joe-3.1-compilesubdir.patch,
  joe-3.1-syntaxsegv.patch
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 schwab@suse.de
- Don't strip binaries.
* Tue Jul  5 2005 uli@suse.de
- build with warnings
- fixed warnings Autobuild objects to (fixes s390x)
* Sun Jun  5 2005 cthiel@suse.de
- update to 3.3
- disabled joe-3.1-compilesubdir.patch
* Wed Jun 23 2004 uli@suse.de
- parse entering/leaving dir msgs from make
* Thu Jun 17 2004 uli@suse.de
- update -> 3.1
* Tue Apr 27 2004 uli@suse.de
- fixed segfault in syntax highlighting
- added highlighting rules for spec files
* Mon Apr 26 2004 uli@suse.de
- update -> 3.0 (UTF-8 support, syntax highlighting)
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Feb  5 2002 egmont@suselinux.hu
- updated to 2.9.8-pre1
* Mon Jan 28 2002 egmont@suselinux.hu
- disabled undo patch, seems to be very buggy
- use relative symlinks instead of absolute ones
- added symlinks for manpages
- added URL
- added defattr(-,root,root) to spec file
* Wed Sep 26 2001 pmladek@suse.cz
- fixed problem with large files (#5833)
  * fixed by joe-2.9.7-pre1
* Thu Sep 13 2001 pmladek@suse.cz
- added three patches from SourceForge, thanks to
  Koblinger Egmont <egmont@suselinux.hu> for hints
  * resize - solves pause after xterm resizing
  * asis - turns off -asis in the default config, as it
    is no longer needed
  * undo - solves a problem with undo and the "Modified" mark
    after many savings
* Fri Aug 10 2001 pmladek@suse.cz
- downgraded to stable version 2.9.5
  * thanks to Koblinger Egmont <egmont@suselinux.hu> and
  his experiences
* Thu Jul 19 2001 pmladek@suse.cz
- updated to version 2.9.6
- config files moved from /usr/lib to /etc
- cleaned up spec file
* Thu May 24 2001 pmladek@suse.cz
- fixed cast warnings on ia64
- fixed runnig on ia64:
  * The argument of the function isblank must be an unsigned
  char or EOF but the function brc sometimes returns MAXINT.
* Fri Mar 30 2001 uli@suse.de
- update -> 2.9.5 (all fixes are still there)
* Thu Mar 15 2001 pblaha@suse.cz
- add build root
* Wed Mar 14 2001 pblaha@suse.cz
- applied patch from Thomas Biege
- This patch protects a user to open a .joerc file,
- that doesn't belongs to him, in public writeable
- directories (like /tmp). Commands can be executed
- via .joerc.
* Fri Jun 23 2000 nadvornik@suse.cz
- added locale patch
- sorted
* Fri May 19 2000 schwab@suse.de
- conf.c: don't redeclare time on ia64
* Tue Apr  4 2000 dipa@suse.de
- a patch that take the resizing of a X terminal into consideration
  +#include <sys/ioctl.h> in tty.c
* Thu Mar  2 2000 kukuk@suse.de
- Move /usr/man -> /usr/share/man
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Aug 24 1999 uli@suse.de
- added -fsigned-char to CFLAGS (PPC)
* Sat Jul 24 1999 garloff@suse.de
- Applied better security fix (w/o unlinking) from thomas@suse.de
* Tue Jul 20 1999 garloff@suse.de
- Additionally added unlink("DEADJOE");
* Tue Jul 20 1999 garloff@suse.de
- Checked in DEADJOE permissions security fix from thomas@suse.de
* Tue Feb  2 1999 ro@suse.de
- conf.c: don't redeclare time on alpha
* Mon Nov 23 1998 max@suse.de
- termcap support is broken with glibc2
  but ncurses seems to work now.
* Fri Sep 18 1998 max@suse.de
- applied Home/End key fix from joe to the other *rc files
* Mon Aug 10 1998 max@suse.de
- added some doc files to the file list
* Fri Dec 12 1997 max@suse.de
- using terminfo again for bugfix reasons
* Tue Oct 28 1997 max@suse.de
- cleaned up generated specfile
- configured for terminfo instead of termcap
- fixed the Home/End key bug
